#!/bin/sh

error() {
  echo "$(basename $0): fatal error, $1 failed"
  exit 1
}

# create a temporary file
tmp=`(mktemp -q /tmp/nvidia.XXXXXX) 2> /dev/null` || tmp="/tmp/nvidia.$$"

paths=" /etc/modutils/aliases    \
        /etc/modules.conf        \
        /etc/conf.modules        "

modconf=""
for path in $paths; do
   if [ -f "$path" ]; then
       modconf=$path
       break
   fi
done

if [ ! -z $modconf ]; then
   # Initialize the permissions on $tmp so that we don't change the
   # permissions of $modconf when we mv it into place
   cp -p $modconf $tmp
   sed '/^alias.*\(NVdriver\|nvidia\)/d'  < $modconf   > $tmp
   if [ -c /dev/.devfsd ]; then
     echo "alias /dev/nvidia*   nvidia" >> $tmp
   else
     echo "alias char-major-195 nvidia" >> $tmp
   fi
   mv -f $tmp $modconf
   test -x /sbin/update-modules && /sbin/update-modules
else
  if [ -f /etc/rc.d/rc.modules ]; then
    # Initialize the permissions on $tmp so that we don't change the
    # permissions of /etc/rc.d/rc.modules when we mv it into place
    cp -p /etc/rc.d/rc.modules $tmp
    sed '/.*\(NVdriver\|nvidia\).*/d' < /etc/rc.d/rc.modules > $tmp
    echo -e "\n/sbin/modprobe nvidia" >> $tmp
    mv -f $tmp /etc/rc.d/rc.modules
  fi
fi

if [ ! -c /dev/.devfsd ]; then
  for i in 0 1 2 3 4 5 6 7; do
      node="/dev/nvidia$i"
      rm -f $node
      mknod $node c 195 $i || error "mknod \"$node\""
      chmod 0666 $node     || error "chmod \"$node\""
  done
  node="/dev/nvidiactl"
  rm -f $node        
  mknod $node c 195 255    || error "mknod \"$node\""
  chmod 0666 $node         || error "chmod \"$node\""
fi

exit 0
